#
# spec file for package po4a
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           po4a
VCS: https://src.suse.de/SLFO-pool/po4a#5497c13ac141ea45a85cb78473d5c5c2426e6b48a48531789150062236aeb8ce
Version:        0.69
Release:        160000.1.5
Summary:        Framework to translate documentation and other materials
License:        GPL-2.0-only
%if "%{_vendor}" == "debbuild"
Group:          text
%else
Group:          Development/Tools/Other
%endif
URL:            https://po4a.org/
Source:         https://github.com/mquinson/po4a/releases/download/v%{version}/%{name}-%{version}.tar.gz

%if "%{_vendor}" == "debbuild"
BuildRequires:  deb-perl-macros
BuildRequires:  docbook
BuildRequires:  docbook-xml
BuildRequires:  docbook-xsl
BuildRequires:  gettext
BuildRequires:  libmodule-build-perl
BuildRequires:  libpod-parser-perl
BuildRequires:  libsgmls-perl
BuildRequires:  libterm-readkey-perl
BuildRequires:  libunicode-linebreak-perl
BuildRequires:  libyaml-tiny-perl
BuildRequires:  perl
BuildRequires:  texlive-binaries
BuildRequires:  texlive-latex-base
BuildRequires:  xsltproc

%else
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  libxslt-tools
BuildRequires:  perl-Module-Build >= 0.40
BuildRequires:  perl-SGMLS >= 1.03ii
BuildRequires:  perl-Term-ReadKey
BuildRequires:  perl-Test-Pod
BuildRequires:  perl-Text-WrapI18N
BuildRequires:  perl-Unicode-LineBreak
BuildRequires:  perl-YAML-Tiny
BuildRequires:  perl-base
BuildRequires:  perl-gettext >= 1.01
BuildRequires:  perl(Pod::Parser)
BuildRequires:  perl(Syntax::Keyword::Try)
# for test suite
BuildRequires:  docbook_4
BuildRequires:  iso_ent
%endif
BuildRequires:  opensp

%{perl_requires}
%if "%{_vendor}" == "debbuild"
#Requires:       ${misc:Depends}
Requires:       gettext
Requires:       libpod-parser-perl
Requires:       libsgmls-perl
Requires:       libyaml-tiny-perl
Requires:       opensp
Recommends:     liblocale-gettext-perl
Recommends:     libterm-readkey-perl
Recommends:     libtext-wrapi18n-perl
Recommends:     libunicode-linebreak-perl
%else
Requires:       gettext-tools
Requires:       perl-SGMLS
Requires:       perl-YAML-Tiny
Requires:       perl(Pod::Parser)
Requires:       perl(Syntax::Keyword::Try)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
%lang_package
%endif

%description
Po4a extracts the translatable material from its input in a PO file.
When the PO file is translated, it re-injects the translation in the structure of the document,
and generates the translated document.
If a string is not translated (i.e. it was not translated or it is "fuzzy"
because the original document was updated), the original string is used.
This permits to provide always up-to-date documentation.

po4a supports currently the following formats:
  * manpages
  * POD
  * XML (generic, DocBook, XHTML, Dia, Guide, or WML)
  * SGML
  * TeX (generic, LaTeX, BibTex or Texinfo)
  * text (simple text files with some formatting, markdown, rubydoc or AsciiDoc)
  * INI
  * YAML
  * KernelHelp

%prep
%setup -q

%build
perl Build.PL installdirs=vendor
./Build

%install
./Build install destdir=%{buildroot} create_packlist=0
%find_lang %{name} --with-man --all-name

%check
# requires texlive, which is too heavy for the package
rm -rf t/fmt-tex.t t/fmt/tex

#run the tests
./Build test

%files
%defattr(644,root,root,755)
%doc NEWS README* TODO
%license COPYING
%attr(755,root,root) %{_bindir}/*
%dir %{perl_vendorlib}/Locale/
%{perl_vendorlib}/Locale/Po4a
%{_mandir}/man1/*
%{_mandir}/man3/*
%{_mandir}/man7/*

%files lang -f %{name}.lang
%defattr(-,root,root)
%dir %{_mandir}/ca
%dir %{_mandir}/de
%dir %{_mandir}/es
%dir %{_mandir}/fr
%dir %{_mandir}/it
%dir %{_mandir}/ja
%dir %{_mandir}/nb
%dir %{_mandir}/nl
%dir %{_mandir}/pl
%dir %{_mandir}/pt
%dir %{_mandir}/pt_BR
%dir %{_mandir}/ru
%dir %{_mandir}/sr_Cyrl
%dir %{_mandir}/uk
%dir %{_mandir}/zh_CHS
%dir %{_mandir}/zh_Hant

%changelog
* Mon Jan 16 2023 dmueller@suse.com
- update to v0.69:
  * Parts of a fenced divs are now translated separately (GitHub's #381)
  * Use the implementation of YFM to parse YAML files too.
  * Numbers and arrays are not quoted anymore in Yaml files, as it should
    be.
  * This adds the yfm_paths option to Markdown and Asciidoc YFM,
  * fixing GitHub's #392 along the way.
  * Please note that '-o keys' is now case-sensitive in Yaml documents.
  * Do not translate nor quote booleans, so that they are not treated as
    string.
  * Correctly handle placeholders of empty elements (GitHub's #389)
  * Translate attributes within attribute-folded inline and placeholder (GH
    [#391])
  * alt attribute of  can be properly handled with:  -o
    'attributes=<image>alt' -o 'inline=<image>' -o foldattributes
  * Thanks k-yaegashi for the pull request fixing both issues
  * Add a deprecation warning to po4a-translate and po4a-updatepo stating
    that po4a is the prefered interface.
  * Rewrite the po4a-gettextize documentation (Debian's #1016695) [Mt].
  * Rewrite the intro of po4a doc, and add a Quick start tutorial [Mt].
* Fri Jul 15 2022 elchevive@opensuse.org
- Update to version 0.67
- Add perl(Syntax::Keyword::Try) to Requires and BuildRequires
  Asciidoc:
  * Support Hugo shortcode on macros (GitHub's #352) [Danilo G. Baio]
  * Support automatically numbered callouts (GitHub's #351) [J.N. Avila]
  * Support line breaks (GitHub's #199) [J.N. Avila]
  gettextization:
  * Deduplicate the msgids, to prevent the structure desynchronizations
  when the same string is used at several locations, with mismatching types.
  (GitHub's #334) [mquinson]
  * Add some tests for the gettextization feature. [mquinson]
  po4a-translate:
  * Do not check whether the po file is uptodate, as it's impossible to do
  that correctly when several master files are merged in the same POT.
  (GitHub's #156) [mquinson]
  Man:
  * Improve the error message when using '.de', '.if', '.ie' to hint about
  the option 'groff_code=verbatim|translate' (GitHub's #361) [mquinson]
  * Implement '.el' (else branch) as translate_joined [mquinson]
  * Implement '.de1' (define with no check) as '.de' [mquinson]
  * Implement '.dei', '.dei1' (define with subst) (Debian's #710678) [MQ]
  * Implement '.it' (input trap) as untranslated (GitHub's #339) [mquinson]
  * Make a sensible warning when user-defined macros are not explained to po4a
  with the 'untranslated' option and friends. [mquinson]
  Markdown:
  * New option 'yfm_lenient' to proceed even if the YAML Front Matter parser fails.
  Useful when your file starts with an horizontal ruler that is not a YFM.
  (GitHub's #365) [mquinson]
  * This introduces a NEW DEPENDENCY: Syntax::Keyword::Try
  * Do not quote the YFM lists to not break them (GitHub's #304) [mquinson].
  Thanks @dbaio for the analysis and @ynojima for an initial patch in doc-l10n-kit.
  xHTML:
  * Add a test for tables and stop claiming that they may be broken
  (GitHub's #366, thanks Petter Reinholdtsen).
  Other bug fixes:
  * Hide an ugly warning about uninitialized string (GitHub's #360) [mquinson]
* Tue Jan 11 2022 elchevive@opensuse.org
- Update to version 0.66
  Asciidoc:
  * Support empty cells in tablecells mode (GitHub's #343) [J.N. Avila]
  * Disable tablecells when table is not in PSV format (GitHub's #343 too) [J.N. Avila]
  Yaml:
  * New option "paths" to select the full paths to extract.
  * The old "key" option (that allows to select any path ending with the given
  key) still works as previously (thanks Oliver Rahner).
  Tests:
  * Make the SGML tests use valid input files to fix brekages on paranoid OSes
  (GitHub's#327 -- thanks newbluemoon for report and fix).
  * Add a new tests that fixes the weird permission settings of the other tests,
  and prevent the users from running the tests as root (GitHub's #332 -- thanks
  Oliver Rahner for stepping on that trap).
  * Fix the testsuite so that it works even if the source is checkouted in an
  arbitrary directory (GitHub's #338).
  po4a-gettextize:
  * Use UTF-8 by default for localized charset.
* Tue Jan 11 2022 elchevive@opensuse.org
- Update to version 0.65
  Asciidoc:
  * Ensure that comments appear in the translated contents, to preserve the document
  structure (Github's #307 and #308). Thanks Jean-Noël Avila for the fix!
  * Add an "nolinting" option to disable lint messages.
  po4a runner:
  * In split mode, allow to group several files within the same POT file.
  * Rename the option 'master:file' to 'pot' for clarity. The old name still works
  (with a warning).
  Tex:
  * Don't use the full absolute file path in #: references of PO files. (Debian's #998196,
  Github's #281)
* Fri Oct 29 2021 elchevive@opensuse.org
- Remove -lang package from Requires
* Thu Sep 16 2021 elchevive@opensuse.org
- Add gettext-tools as Requires (boo#1190403)
* Mon Sep 13 2021 elchevive@opensuse.org
- Update to version 0.64
- Remove a69b48eda3ebd66eec30a34a377c7a00c6f8e36c.patch (included in this
  release)
  Asciidoc:
  * Detect sublevel description lists with :::
  * Don't split in attributes include:: and ifeval:: lines (Github's #298)
  Pod:
  * Don't wrap textblocks, as it may break C<> markup (similar to Github's #242)
  Core:
  * Mitigate Perl bug #18604 (simplify a regexp into a substring index) (Github's #302)
  * Improve the consistency of all our module lists (related to Github's #136)
  Thanks Viet Than.
* Fri Sep 10 2021 mrueckert@suse.de
- backport https://github.com/mquinson/po4a/commit/a69b48eda3ebd66eec30a34a377c7a00c6f8e36c.patch
  this works around a memory leak in perl
  https://github.com/Perl/perl5/issues/18604
  https://github.com/mquinson/po4a/issues/317
  https://github.com/mquinson/po4a/issues/302
* Sat Jul 10 2021 pau.garcia@suse.com
- debbuild does not understand patterns like man[1357] so desaggregating
  into man1, man3, etc for Ubuntu and Debian packages
* Thu Jun 24 2021 pau.garcia@suse.com
- Make po4a buildable on Debian and Ubuntu. This is required for GitHub Actions,
  which only provide Ubuntu machines as workers.
  Uyuni has GH Actions to automagically convert the English AsciiDoc files to
  gettext, commit to the uyuni-docs repository and then openSUSE WebLate will
  pull the gettext files.
* Mon Mar  8 2021 pau.garcia@suse.com
- Update to version 0.63
- Asciidoc: properly deal with the YAML Front Matter, when one is found.
- Texinfo: add support for @tindex (Github's #284)
- Yaml: follow the reference style of YAML Front Matter in Markdown module
  to fix the GitHub issue #289. (GitHub's #292)
- Portability: fix po4a(1) on Windows (GitHub's #293)
* Mon Dec  7 2020 pau.garcia@suse.com
- Update to version 0.62
- Install additional translated manpages: de, es, fr, it, ja, nl, pt_BR, ru
  po4a tool:
  * Improve po_paths on misconfigurations, improve doc and error messages.
  Asciidoc:
  * Unwrap all paragraphs by default (Github's #242).
  Introduce "forcewrap" option to re-enable line wrapping on output.
  * Support definition list continuations with indent (Github's #273)
  DocBook:
  * Mark xreflabel attributes as translatable (GitHub's #267).
  Translations:
  Updated: Croatian, Chinese (simplified), Dutch, French, German, Hungarian,
  Italian, Norwegian Bokmål, Portuguese, Portuguese (Brazil), Russian,
  Serbian (cyrillic), Spanish and Ukrainian
* Mon Nov  9 2020 elchevive@opensuse.org
- Also add perl(Pod::Parser) to Requires, otherwise POD generation fail
  (boo#1178446)
* Fri Oct 30 2020 dimstar@opensuse.org
- Add perl(Pod::Parser) BuildRequires: explicitly checked for by
  the build system. Used to be part of perl, but is no longer so in
  perl 5.32.
* Thu Sep  3 2020 elchevive@opensuse.org
- Fix boo#1175977
- Added missing Requires (perl-SGMLS and perl-YAML-Tiny) and BuildRequires
  (perl-Test-Pod) and removed not used anymore (perl-HTML-Parser)
* Sun Aug 16 2020 pau.garcia@suse.com
- Update to version 0.61
  po4a tool:
  * Robustify --srcdir and --destdir: When building the schroot package,
  these paths happen to be soft links to the same directory, making po4a
  believe that the POT file is specified twice (to the same value). po4a
  is now ignoring these dups.
  Translations:
  Updated: Chinese, Czech, Dutch, French, German, Portuguese, Portuguese
  (Brazil), Serbian and Ukrainian.
* Sun Aug 16 2020 pau.garcia@suse.com
- Update to version 0.60
  Asciidoc:
  * Introduce "compat" option to parse like asciidoc or asciidoctor.
  Text (and Markdown):
  * Fix the support of nested lists.
  Other:
  * Remove the experimental C extension that was never built, distributed,
  tested nor modified since 2007.
  XML:
  * Provide a meaningful message when the translators butcher the <placeholder>
  attributes instead of truncating the file.
  Translations:
  Updated: Chinese, Croatian, Dutch, French, German, Norwegian Bokmål, Portuguese
  (Brazil), Serbian and Ukrainian.
* Fri Nov 22 2019 elchevive@opensuse.org
- updated to version 0.57
  AsciiDoc:
  * Introduce option tablecells to process cells in tables.
  * Widen accepted characters in the term part of definition list
  po4a tool:
  * Don't use single quotes to protect command line arguments, as it fails on
  Windows
  Translations:
  New translation: Arabic
  Updated: Dutch, French, Italian, Japanese, Norwegian Bokmål,
  Portuguese (Brazil) and Ukrainian
* Fri Jun  7 2019 elchevive@opensuse.org
- updated to version 0.56
  AsciiDoc:
  * Fix Asciidoc unindented lists
  * Make Asciidoc Tables nowrap and support current format
  * Do not include table fences in pot file
  * Add option to prevent translation of target of image blocks
  AsciiDoc:
  * Introduce option tablecells to process cells in tables.
  * Widen accepted characters in the term part of definition list
  po4a tool:
  * Don't use single quotes to protect command line arguments, as it
  fails on Windows
  Translations:
  New translation: Arabi.
  Updated: Dutch, French, Italian, Japanese, Norwegian Bokmål, Portuguese
  (Brazil) and Ukrainian.
* Tue Jan 29 2019 elchevive@opensuse.org
- updated to version 0.55
  AsciiDoc:
  * Fix Asciidoc unindented lists
  * Make Asciidoc Tables nowrap and support current format
  * Do not include table fences in pot file
  * Add option to prevent translation of target of image blocks
  Markdown:
  * Improve markdown ruler parsing, and add test.
  * Add markdown fenced code block parsing, and add test.
  Sgml:
  * Avoid deprecated unescaped left brace in regex to get ready for Perl 5.32.
  (deb#903735)
  TransTractor:
  * Ensure to split lines before addendum operation without loss or addition of
  newline. With this change, addendum behavior is more intuitive.(deb#518218)
  Wml:
  * Fix longstanding error regarding comments at the beginning of a file.
  Xml, Docbook:
  * Document XML tag behavior customization with example to help use case
  specific customization. (deb#515763)
  * Debug output enhancement to help people understand what exactly happening
  inside po4a.
  * Extensive POD and code comment additions and updates.
  po4a tool:
  * Add pot_in feature to support the secondary master file for the base of
  POT/PO file generation.
  Test:
  * Add XML test cases with po4a including addendum, tag customization, and
  pot_in feature.
  Translations:
  New translation to Chinese and Chinese Simplified
  Updated: Dutch, Estonian, French German, Italian, Norwegian Bokmål,
  Portuguese (Brazil), Russian, Spanish, Swedish, Ukrainian and Vietnamese.
* Tue Aug  7 2018 elchevive@opensuse.org
- updated to version 0.54
- change links from Alioth (shutting down) to GitHub
- disable t\09-html (dropped on next version - obsolete module)
- new dependecy (perl-yaml-tiny) for new module Yaml
  Asciidoc:
  * Fixed a bug that prevented the asciidoc module to parse correctly four
  characters table marks
  * Handle macros with empty target
  Man:
  * Support .MT and .ME macros for e-mail address markup (deb#900965)
  * Support .OP, .SY, and .YS macros for command synopses
  po4a tool:
  * po4a --keep-translations will not remove your existing translations
  if they fall below the threshold
  po4a-build tool:
  * Remove it and all related shell scripts and makefile chunks. It is
  deprecated by the po4a tool since a long time
  Yaml:
  * New module
  * Fix the behavior with utf-8 files
  * Add the references from the Yaml file to the po file
  Texinfo:
  * Fix handling of spaces in menu descriptions (deb#758851)
  Text:
  * Fix the parsing of fortunes files, which had been broken since
  v0.43. The handling has changed a bit, all msgids are now marked as
  "no-wrap", because the word wrap in fortunes files usually matters.
  * Remove the option for parsing AsciiDoc. There has been a standalone
  module for nearly five years, released with v0.45
  * Support pandoc's bibliographic information (title, author, date)
  at the beginning of a markdown file. Also fix a trailing newline
  in some markdown titles (deb#894977)
  Documentation:
  * Fix many typos and other issues found
  * Remove the last references to the alioth servers and mailing lists.
  Translations:
  Updated: Dutch, Estonian, French, German, Italian, Norwegian Bokmål,
  Portuguese, Portuguese (Brazil), Russian, Swedish, Ukrainian, and Vietnamese
* Mon Aug 28 2017 elchevive@opensuse.org
- updated to version 0.52
  Core:
  * po4a-translate complains if the input po file is outdated (deb#637288).
  * teach po4a-updatepo about the --porefs options that was already documented.
  * rename --porefs values after msgmerge option's name: noline->file
  and none->never. (deb#775708).
  po4a:
  * New option --no-update to not touch the po files. (deb#599179)
  * Checking po file is fine. Failing if the file does not exist isn't.
  (deb#858934)
  * Check the validity of po files before using them (deb#855431)
  AsciiDoc:
  * Properly deal with item text missing its leading indent.
  * Allow empty attribute lists, by bexelbie.
  * Further bug fixing to handle the git documentation.
  * Fix some bugs, around style macros
  * Correctly handle list literal paragraph
  Man:
  * Add support for the tab(<character>) global option inside .TS/.TE.
  Also tidy up trailing newline handling in text blocks: Since that
  trailing newling must be there, no need to translate it explicitly.
  (deb#847754).
  Text:
  * Add an option to treat Key/Value pairs as verbatim
  * Add a neverwrap option to prevent any wrapping (deb#824753)
  RubyDoc:
  * New module by Francesco Poli (deb#827936)
  Wml:
  * Make title translatable.
  XML:
  * Add an option to escape all quotes, for android.
  * Add an option to not wrap attributes.
* Thu Sep 15 2016 elchevive@opensuse.org
- updated to version 0.48
- Remove BuildRequires if's for older versions (opensuse<=12.1)
  * Major changes in release 0.48
  SGML:
  * Use OpenSP as an underlying engine instead of the deprecated SP
  Thanks to Neil Roeth (deb#809477 and deb#280882)
  Translations:
  * Update Japaneese.
  * Fix formating issue in pt translation
* Fri Aug 28 2015 elchevive@opensuse.org
- updated to version 0.47
  * Major changes in release 0.47
  Man:
  * Fix: don't add supirious lines around \# lines (deb#786642)
  Documentation:
  * Bugfix: poref is a command line option (deb#775707)
  Translations:
  * Update Italian
  Other:
  * Port our regex to Perl 5.22 (deb#788706)
* Thu May 21 2015 elchevive@opensuse.org
- updated to version 0.46
  * Major changes in release 0.46
  Man:
  * Fix handling of preprocessor lines (deb#744366)
  * Fix handling of tbl's textblocks (deb#748601)
  Sgml:
  * Silence a warning about useless greediness modifier (deb#779435)
  Translations:
  * Update Dutch, Vietnamese, and Brazilian Portuguese (deb#782393, deb#776896, and deb#735644)
  Documentation:
  * Update Brazilian Portuguese (deb#735644)
* Wed Nov 19 2014 bwiedemann@suse.com
- fix download link
* Thu Jan 30 2014 elchevive@opensuse.org
- drop po4a-0.44-use-tempfile-correctly.patch
- updated to version 0.45
  po4a:
  * Fix usage of File::Temp::tempfile to allow using Perl >= 5.18.
  Asciidoc:
  * Make it a standalone format.
  Docbook:
  * Make <beginpage> inline.
  Ini:
  * Add key parameter as an automatic comment.  This allows using
  po4a-gettextize on ini files.
  LaTeX:
  * Fix handling of optional parameters in newtheorem command.
  Po:
  * Fix computation of timezone written into PO files.
  Sgml:
  * Fix failing tests with recent Docbook DTD.
* Mon Jun 24 2013 elchevive@opensuse.org
- Add po4a-0.44-use-tempfile-correctly.patch to fix tempfile build
  errors on Perl >-5.18 by replacing 'File::Temp->tempfile' with
  'File::Temp::tempfile'
- Source URL corrected
* Mon Apr 15 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Sun Jan 27 2013 coolo@suse.com
- do not buildrequire texlive
* Sun Oct 21 2012 elchevive@opensuse.org
- update to version 0.44:
  Fix packaging issues with 0.43
* Fri Oct 19 2012 elchevive@opensuse.org
- update to version 0.43:
  po4a:
  * Add --porefs option to change how file locations are written into
  the POT file (and thus into the PO files also).
  po4a-updatepo po4a Po:
  * Extend the --porefs option, add a new 'counter' value to replace
  line number by an increasing counter.
  An optional ",nowrap" or ",wrap" specifier can be added to tell
  whether file locations are written on a single line or wrapped on
  several lines.  Default is ",nowrap", it will be changed to ",wrap"
  in a future release.
  Man:
  * Make .UR/.UE macros inline.
  * Add macros used in several NetBSD man pages: %%I %%U Brc Bro Lp Lk
  Text:
  * Fix two line titles in AsciiDoc format.
  * Let AsciiDoc format handle many more styles.
  * Add support for automatic comments in AsciiDoc format.
* Thu May 17 2012 elchevive@opensuse.org
- update to version 0.42:
  po4a:
  * Allow adding command-line options after config file.
  Text:
  * Add support for control files.
  msguntypot:
  * Do not remove obsolete entries from PO files.
  documentation translations updates
  * New German translations
  * Updated Spanish translations
  * Updated French translations
  * Updated Japanese translations
  * Updated Polish translations
* Fri Mar 23 2012 elchevive@opensuse.org
- Reflect changes on libxslt package (-tool subpackage created)
* Wed Mar 21 2012 elchevive@opensuse.org
- Add perl_requires and libxslt1
* Mon Feb 13 2012 prusnak@opensuse.org
- spec cleanup
* Wed Jan  5 2011 elchevive@opensuse.org
- enable tests and split -lang package
* Tue Jan  4 2011 elchevive@opensuse.org
- initial packaging
